@@ -17,6 +17,6 @@
 
 from __future__ import annotations
 
-__version__ = '2.18.7'
+__version__ = '2.20.1'
 __author__ = 'Ansible, Inc.'
-__codename__ = "Fool in the Rain"
+__codename__ = "Good Times Bad Times"
