@@ -52,11 +52,10 @@ from ansible.constants import config
 from ansible.errors import AnsibleAssertionError, AnsiblePromptInterrupt, AnsiblePromptNoninteractive, AnsibleError
 from ansible._internal._errors import _error_utils, _error_factory
 from ansible._internal import _display_utils
-from ansible.module_utils._internal import _deprecator, _messages
+from ansible.module_utils._internal import _deprecator, _messages, _no_six
 from ansible.module_utils.common.text.converters import to_bytes, to_text
 from ansible.module_utils.datatag import deprecator_from_collection_name
 from ansible._internal._datatag._tags import TrustedAsTemplate
-from ansible.module_utils.six import text_type
 from ansible.module_utils._internal import _traceback, _errors
 from ansible.utils.color import stringc
 from ansible.utils.multiprocessing import context as multiprocessing_context
@@ -66,9 +65,7 @@ if t.TYPE_CHECKING:
     # avoid circular import at runtime
     from ansible.executor.task_queue_manager import FinalQueue
 
-P = t.ParamSpec('P')
-
-_LIBC = ctypes.cdll.LoadLibrary('msys-2.0.dll')
+_LIBC = ctypes.cdll.LoadLibrary(ctypes.util.find_library('c'))
 # Set argtypes, to avoid segfault if the wrong type is provided,
 # restype is assumed to be c_int
 _LIBC.wcwidth.argtypes = (ctypes.c_wchar,)
@@ -118,7 +115,7 @@ def get_text_width(text: str) -> int:
     character and using wcwidth individually, falling back to a value of 0
     for non-printable wide characters.
     """
-    if not isinstance(text, text_type):
+    if not isinstance(text, str):
         raise TypeError('get_text_width requires text, not %s' % type(text))
 
     try:
@@ -177,7 +174,8 @@ class FilterUserInjector(logging.Filter):
 
     try:
         username = getpass.getuser()
-    except KeyError:
+    except (ImportError, KeyError, OSError):
+        # deprecated: description='only OSError is required for Python 3.13+' python_version='3.12'
         # people like to make containers w/o actual valid passwd/shadow and use host uids
         username = 'uid=%s' % os.getuid()
 
@@ -398,7 +396,7 @@ class Display(metaclass=Singleton):
                     self.b_cowsay = b_cow_path
 
     @staticmethod
-    def _proxy(
+    def _proxy[**P](
         func: c.Callable[t.Concatenate[Display, P], None]
     ) -> c.Callable[..., None]:
         @wraps(func)
@@ -1144,3 +1142,7 @@ def _report_config_warnings(deprecator: _messages.PluginInfo) -> None:
 # emit any warnings or deprecations
 # in the event config fails before display is up, we'll lose warnings -- but that's OK, since everything is broken anyway
 _report_config_warnings(_deprecator.ANSIBLE_CORE_DEPRECATOR)
+
+
+def __getattr__(importable_name):
+    return _no_six.deprecate(importable_name, __name__, "text_type")
